
Scrapy_Rabbit
======


Overview
========

将Scrapy与RabbitMQ进行结合，解决断点续爬，采集进度可视化并且提高代码复用性


Requirements
============

* Python 3.6+
* Works on Linux, Windows, macOS, BSD

Install
=======

The quick way::

    pip install scrapy-rabbit

